@@ -19,8 +19,8 @@ git add openshift OWNERS_ALIASES OWNERS Makefile
 git commit -m ":open_file_folder: Update openshift specific files."
 
 # Apply patches .
-git apply openshift/patches/*
-cat openshift/999-webhook-policy_append.patch >> openshift/release/knative-eventing-ci.yaml
+# git apply openshift/patches/*
+make RELEASE=ci generate-release
 git commit -am ":fire: Apply carried patches."
 
 git push -f openshift release-next
