@@ -27,8 +27,8 @@ func TestTypesImplements(t *testing.T) {
 		iface    duck.Implementable
 	}{
 		// PingSource
-		{instance: &ApiServerSource{}, iface: &duckv1.Conditions{}},
-		// ContainerSource
+		{instance: &PingSource{}, iface: &duckv1.Conditions{}},
+		// ApiServerSource
 		{instance: &ApiServerSource{}, iface: &duckv1.Conditions{}},
 		// SinkBinding
 		{instance: &SinkBinding{}, iface: &duckv1.Conditions{}},
